@@ -5,7 +5,7 @@ use strict;
 use base qw/Cache::Funky::Storage/;
 use Cache::Memcached;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub new {
     my $class = shift;
@@ -21,6 +21,9 @@ sub set {
     my $s     = shift;
     my $key   = shift;
     my $value = shift;
+    my $id    = shift;
+
+    $key = $id ? $key . ':' . $id : $key ;
 
     $s->{memcached}->set( $key , $value );
 
@@ -30,6 +33,9 @@ sub set {
 sub get {
     my $s     = shift;
     my $key   = shift;
+    my $id    = shift;
+
+    $key = $id ? $key . ':' . $id : $key ;
 
     return $s->{memcached}->get( $key );
 
@@ -38,6 +44,9 @@ sub get {
 sub delete {
     my $s     = shift;
     my $key   = shift;
+    my $id    = shift;
+
+    $key = $id ? $key . ':' . $id : $key ;
 
     $s->{memcached}->delete( $key );
 }
@@ -63,6 +72,7 @@ Memcached Storage for L<Cache::Funky>
   
   __PACKAGE__->setup('Storage::Memcached' => { servers => [ '127.0.0.1:12345' ] });
   __PACKAGE__->register( 'foo', sub { time } );
+  __PACKAGE__->register( 'boo', sub { shift . '_' . `date` } ); # * date: $id + _Tue May 1 21:53:36 JST 2007
   
   1;
 
@@ -77,9 +87,23 @@ run.pl
   sleep(3);
   say ( MyCache->foo() );
   
-  MyCache->delete(qw/foo/);
+  MyCache->delete('foo');
   say ( MyCache->foo() );
 
+  say ( MyCache->boo('id1') );
+  say ( MyCache->boo('id2') );
+    
+  sleep 10;
+  say ( MyCache->boo('id1') );
+    
+  # only remove id1
+  MyCache->delete('boo', 'id1');
+
+  say ( MyCache->boo('id1') );
+  say ( MyCache->boo('id2') );
+
+  MyCache->deletes([qw/foo boo/]);
+
 =head1 METHOD
 
 =head2 new
